%
% plot the phase transition models
% 
% for details see: 
%  Identification of phase fraction-temperature curves from heat capacity 
%  data for numerical modeling of heat transfer in commercial paraffin waxes
%  Tilman Barz, Johannes Krmer, and Johann Emhofer
%  Energies
% 
% tilman.barz@ait.ac.at
% 17/09/2020
% 


clc
clear


%% --- select here -> 
%    whichPCM = 'RT-9HC'; 
%    whichPCM = 'RT-4'; 
%    whichPCM = 'RT0'; 
%    whichPCM = 'RT2HC'; 
%    whichPCM = 'RT3HC'; 
%    whichPCM = 'RT4'; 
%    whichPCM = 'RT5'; 
%    whichPCM = 'RT5HC'; 
%    whichPCM = 'RT8'; 
%    whichPCM = 'RT8HC'; 
%    whichPCM = 'RT9'; 
%    whichPCM = 'RT10'; 
%    whichPCM = 'RT10HC'; 
%    whichPCM = 'RT11HC'; 
%    whichPCM = 'RT12'; 
%    whichPCM = 'RT15'; 
%    whichPCM = 'RT18HC'; 
%    whichPCM = 'RT21'; 
%    whichPCM = 'RT21HC'; 
%    whichPCM = 'RT22HC'; 
%    whichPCM = 'RT24'; 
   whichPCM = 'RT25HC'; 
%    whichPCM = 'RT26'; 
%    whichPCM = 'RT28HC'; 
%    whichPCM = 'RT31'; 
%    whichPCM = 'RT35'; 
%    whichPCM = 'RT35HC'; 
%    whichPCM = 'RT42'; 
%    whichPCM = 'RT44HC'; 
%    whichPCM = 'RT47'; 
%    whichPCM = 'RT50'; 
%    whichPCM = 'RT54HC'; 
%    whichPCM = 'RT55'; 
%    whichPCM = 'RT60'; 
%    whichPCM = 'RT62HC'; 
%    whichPCM = 'RT64HC'; 
%    whichPCM = 'RT65'; 
%    whichPCM = 'RT69HC'; 
%    whichPCM = 'RT70HC'; 
%    whichPCM = 'RT80HC'; 
%    whichPCM = 'RT82'; 
%    whichPCM = 'RT90HC'; 
%    whichPCM = 'RT100'; 
%    whichPCM = 'RT100HC'; 

%% --- load the model parameters into data struct
eval(['load ' whichPCM '.mat;']);

   
%% --- compute properties -------------------------
    cp_s = data.cp_solid;
    cp_l = data.cp_liquid;
    dht  = data.phTrEnth;
    ppStruct_H  = data.ppStruct_H;

evalPts = [data.xm_heat(1):0.05:data.xm_heat(end)];
[ cc ic yy] = evaluateSplines(ppStruct_H ,evalPts,cp_l,cp_s,dht);


%% --- plot ---------------------------------------
    xlimi_H = [data.xm_heat(1) data.xm_heat(end)];
    trRange = data.rangeTmelting;
    ftsz = 12;
    
figure();

h_ax1 = subplot(3,1,1);
    
    hp11 = plot(evalPts,ic, 'b-', 'Markersize',8,'MarkerFaceColor','r'); 
    hold on;
    set(h_ax1,'xlim',xlimi_H);
    grid on;
    set(h_ax1,'FontSize',ftsz);
    ylabel('$h(T)\!-\!h(T_{\mathrm{ref}})\;$ [kJ/(kg)]','FontSize',ftsz,'Interpreter','latex');
    xlabel('$T$ [$^\circ$C]','FontSize',ftsz,'Interpreter','latex');

    str = ['Rubitherm ' data.PCMname '  phase transition model'];
    title(str,'Interpreter','NONE','FontSize',ftsz)
   
h_ax2 = subplot(3,1,2);
    
    hp11 = plot(evalPts,cc, 'b-', 'Markersize',8,'MarkerFaceColor','r'); 
    hold on;
    set(h_ax2,'xlim',xlimi_H);
    grid on;
    set(h_ax2,'FontSize',ftsz);
    ylabel('$\tilde{c}(T)\;$ [kJ/(kg$\cdot$K)]','FontSize',ftsz,'Interpreter','latex');
    xlabel('$T$ [$^\circ$C]','FontSize',ftsz,'Interpreter','latex');

h_ax3 = subplot(3,1,3);
    
    hp11 = plot(evalPts,yy, 'b-', 'Markersize',8,'MarkerFaceColor','r'); 
    hold on;
    set(h_ax3,'xlim',xlimi_H);
    grid on;
    set(h_ax3,'FontSize',ftsz);
    ylabel('$\xi(T)\;$ [-]','FontSize',ftsz,'Interpreter','latex');
    xlabel('$T$ [$^\circ$C]','FontSize',ftsz,'Interpreter','latex');
   